#ifndef SDL_WIN_H
#define SDL_WIN_H

/*!
  \file
  \brief SDL  Windows lCeBu

  \author Satofumi KAMIMURA

  $Id$
*/

// !!! {́Astatic link 悤 SDL bp[͂...
// !!! Ƃ肠Aۗ
#include <SDL.h>

#endif /* !SDL_WIN_H */
